/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.component.sushi


import groovy.util.ConfigObject;
import metridoc.sushi.SushiRunner;
import metridoc.sushi.SushiTemplate;
import metridoc.utils.Assert;

import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.apache.camel.spi.Registry;
import org.apache.http.client.ResponseHandler;
import org.joda.time.DateTime;
import org.joda.time.format.DateTimeFormat;
import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.DateTimeFormatterBuilder;

/**
 *
 * @author Narine Ghochikyan
 *
 */
class SushiProcessor implements Processor {
	ResponseHandler responseHandler;
	static final DateTimeFormatter dateTimeFormatter = DateTimeFormat.forPattern("yyyy-MM-dd");//'T'HH:mm:ss")
	
	@Override
	public void process(Exchange exchange) throws Exception {
		//Not sure why when called from outside (sushi-client) 
		//exchange.getIn().getBody(ConfigObject.class) returns null
		ConfigObject config = (ConfigObject)exchange.getIn().getBody();
		Map paramMap = getParamMap(config)	
		SushiTemplate sushiTemplate = new SushiTemplate(paramMap);
		Object result = new SushiRunner().execute(sushiTemplate, responseHandler);
		exchange.getOut().setBody result
	}
	
	static Map getParamMap(ConfigObject config){
		Map paramMap = config.flatten();
		if(config.containsKey("monthsCount") && config.monthsCount > 0){
			Assert.isTrue(!config.containsKey("beginDate") && !config.containsKey("endDate"),
				"monthsCount should not be specified along with beginDate and/or endDate")
			
			DateTime currentDate = new DateTime();
			DateTime endDate = currentDate.dayOfMonth().withMaximumValue()
			int ignoreMonths = 1; 
			if(config.containsKey("ignoreMonths") && config.ignoreMonths > 0){
				ignoreMonths += config.ignoreMonths
			}
			endDate = endDate.minusMonths(ignoreMonths)
			DateTime beginDate = endDate.withDayOfMonth(1).minusMonths(config.monthsCount - 1)
			
			paramMap.put("beginDate", dateTimeFormatter.print(beginDate))
			paramMap.put("endDate", dateTimeFormatter.print(endDate))
		}

		paramMap.remove "monthsCount"
		paramMap.remove "ignoreMonths"
		return paramMap;	
	}
}
