/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.sushi

import groovy.text.SimpleTemplateEngine
import java.text.SimpleDateFormat

/**
 * Created by IntelliJ IDEA.
 * User: tbarker
 * Date: 5/10/11
 * Time: 3:18 PM
 * To change this template use File | Settings | File Templates.
 */
class SushiTemplate {
    private static final String DEFAULT = "NA"
    def reportRequestId = DEFAULT
    def dateFormatter = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss")
    def created = dateFormatter.format(new Date())
    def requestorId = "demo"
    def requestorName = DEFAULT
    def requestorEmail = DEFAULT
    def customerId = "demo"
    def customerName = DEFAULT
    def reportName = "JR1"
    def reportRelease = 3
    def beginDate = "2008-01-01";
    def endDate = "2009-12-31";
    def sushiUrl = "http://projecteuclid.org/sushi/16/service.cgi"
    def basicUsername
    def basicPassword
    def sushiProviderName
    def soapAction = "SushiService:GetReportIn"
    def soapHeader = ""

    String getSoap() {
        def binding = [reportRequestId: reportRequestId,
                created: created,
                requestorId: requestorId,
                requestorName: requestorName,
                requestorEmail: requestorEmail,
                customerId: customerId,
                soapHeader: soapHeader,
                customerName: customerName,
                reportName: reportName,
                reportRelease: reportRelease,
                beginDate: beginDate,
                endDate: endDate,
        ]

        def soapTemplate = '''
            <soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/"
                  xmlns:coun="http://www.niso.org/schemas/sushi/counter"
                  xmlns:sus="http://www.niso.org/schemas/sushi">

                <soapenv:Header>${soapHeader}</soapenv:Header>
                <soapenv:Body>
                    <coun:ReportRequest Created="${created}" ID="${reportRequestId}">
                        <sus:Requestor>
                            <sus:ID>${requestorId}</sus:ID>
                            <sus:Name>${requestorName}</sus:Name>
                            <sus:Email>${requestorEmail}</sus:Email>
                        </sus:Requestor>
                        <sus:CustomerReference>
                            <sus:ID>${customerId}</sus:ID>
                            <!--Optional:-->
                            <sus:Name>${customerName}</sus:Name>
                        </sus:CustomerReference>
                        <sus:ReportDefinition Name="${reportName}" Release="${reportRelease}">
                            <sus:Filters>
                                <sus:UsageDateRange>
                                    <sus:Begin>${beginDate}</sus:Begin>
                                    <sus:End>${endDate}</sus:End>
                                </sus:UsageDateRange>
                            </sus:Filters>
                        </sus:ReportDefinition>
                    </coun:ReportRequest>
                </soapenv:Body>
            </soapenv:Envelope>
        '''

        def engine = new SimpleTemplateEngine()
        engine.createTemplate(soapTemplate).make(binding).toString()
    }
}
